
/*****
 ForgetMeNot, Light
*****/

#include <ESP8266WiFi.h>
#include <PubSubClient.h>

// Change the credentials below, so your ESP8266 connects to your network. USE A HOTSPOT! Proper WiFi does not work for some reason
const char* ssid = "<WIFI_SSID>";
const char* password = "<WIFI_PASSWORD>";

// Run Mosquitto, do "ifconfig" and get the IP address of your laptop on the HOTSPOT's interface, and add it here
const char* mqtt_server = "<YOUR_LOCAL_MQTT_BROKER_IP>";
 
// Initializes the espClient
WiFiClient espClient;
PubSubClient client(espClient);

// Set pins
#define INPUT_PIN A0

// 0 means the light is off
int currentLightStatus = 0;


// This function connects your ESP8266 to your network
void setup_wifi() {
  delay(10);
  // We start by connecting to a WiFi network
  Serial.begin(9600);
  Serial.println();
  Serial.print("Connecting to ");
  Serial.println(ssid);
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println("");
  Serial.print("WiFi connected - ESP IP address: ");
  Serial.println(WiFi.localIP());
}

// This functions reconnects your ESP8266 to your MQTT broker
void reconnect() {
  // Loop until we're reconnected
  while (!client.connected()) {
    Serial.print("Attempting MQTT connection...");
    // Attempt to connect
    if (client.connect("ESP8266Light")) {
      Serial.println("connected");  
      client.subscribe("house/light");
    } else {
      Serial.print("failed, rc=");
      Serial.print(client.state());
      Serial.println(" try again in 1 seconds");
      // Wait 5 seconds before retrying
      delay(1000);
    }
  }
}

// The setup function sets your ESP pins to Outputs, starts the serial communication at a baud rate of 9600, sets your mqtt broker
void setup() {
  pinMode(INPUT_PIN, INPUT_PULLUP);
  Serial.begin(9600);
  setup_wifi();
  client.setServer(mqtt_server, 1883);
}

void loop() {
  // This part ensures that you ESP is connected to your broker
  if (!client.connected()) {
    reconnect();
  }
    
  // Set the light threshold according to your lamp
  // In our case, 150 was enough to distinguish between daylight and light emitting from our lamp
  int lightVal = analogRead(INPUT_PIN);
  int lightStatus = lightVal > 150 ? 1 : 0;
  char* msg;

  if(lightStatus != currentLightStatus){
    currentLightStatus = lightStatus;
    if(currentLightStatus == 1){
      msg = "on";
    }else{
      msg = "off";
    }
    client.publish("house/light",msg);
    Serial.print("sent light is  ");
    Serial.println(msg);
    delay(500);
  }
  Serial.println(lightVal);
} 
